@@ -4,7 +4,9 @@
 package org.gcube.portlets.user.td.gwtservice.client.rpc;
 
 import java.util.ArrayList;
+import java.util.HashMap;
 
+import org.gcube.portlets.user.td.gwtservice.shared.chart.ChartTopRatingSession;
 import org.gcube.portlets.user.td.gwtservice.shared.codelisthelper.CodelistMappingSession;
 import org.gcube.portlets.user.td.gwtservice.shared.csv.AvailableCharsetList;
 import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVExportSession;
@@ -13,16 +15,21 @@ import org.gcube.portlets.user.td.gwtservice.shared.csv.CheckCSVSession;
 import org.gcube.portlets.user.td.gwtservice.shared.extract.ExtractCodelistSession;
 import org.gcube.portlets.user.td.gwtservice.shared.file.FileUploadMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.file.HeaderPresence;
+import org.gcube.portlets.user.td.gwtservice.shared.geometry.GeometryCreatePointSession;
+import org.gcube.portlets.user.td.gwtservice.shared.geospatial.GeospatialCreateCoordinatesSession;
+import org.gcube.portlets.user.td.gwtservice.shared.geospatial.GeospatialDownscaleCSquareSession;
 import org.gcube.portlets.user.td.gwtservice.shared.history.OpHistory;
 import org.gcube.portlets.user.td.gwtservice.shared.history.RollBackSession;
 import org.gcube.portlets.user.td.gwtservice.shared.json.JSONExportSession;
 import org.gcube.portlets.user.td.gwtservice.shared.licenses.LicenceData;
 import org.gcube.portlets.user.td.gwtservice.shared.map.MapCreationSession;
+import org.gcube.portlets.user.td.gwtservice.shared.monitor.BackgroundOperationMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.monitor.BackgroundOperationMonitorSession;
 import org.gcube.portlets.user.td.gwtservice.shared.monitor.OperationMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.monitor.OperationMonitorSession;
 import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXExportSession;
 import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXImportSession;
+import org.gcube.portlets.user.td.gwtservice.shared.share.ShareRule;
 import org.gcube.portlets.user.td.gwtservice.shared.share.ShareTabResource;
 import org.gcube.portlets.user.td.gwtservice.shared.share.ShareTemplate;
 import org.gcube.portlets.user.td.gwtservice.shared.source.SDMXRegistrySource;
@@ -33,7 +40,6 @@ import org.gcube.portlets.user.td.gwtservice.shared.task.ValidationsTasksMetadat
 import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateApplySession;
 import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateData;
 import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateDeleteSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.RefColumn;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TableData;
@@ -42,6 +48,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.tr.batch.OccurrencesForRepla
 import org.gcube.portlets.user.td.gwtservice.shared.tr.batch.ReplaceBatchColumnSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.clone.CloneTabularResourceSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.AddColumnSession;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.column.ChangeColumnsPositionSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.DeleteColumnSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.LabelColumnSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.ReplaceColumnSession;
@@ -56,6 +63,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.tr.replacebyexternal.Replace
 import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.RemoveResourceSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.ResourceTDDescriptor;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.ResourceTDType;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.SaveResourceSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.DeleteRowsSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.DuplicatesSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.EditRowSession;
@@ -69,6 +77,10 @@ import org.gcube.portlets.user.td.gwtservice.shared.tr.union.UnionSession;
 import org.gcube.portlets.user.td.gwtservice.shared.uriresolver.UriResolverSession;
 import org.gcube.portlets.user.td.gwtservice.shared.user.UserInfo;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnDataType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.PeriodDataType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ValueDataFormat;
 
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.user.client.rpc.AsyncCallback;
@@ -87,11 +99,27 @@ public interface TDGWTServiceAsync {
 
 	void hello(AsyncCallback<UserInfo> callback);
 
-	void restoreUISession(AsyncCallback<TRId> callback);
+	void pendingTasksRetrieve(AsyncCallback<Integer> callback);
+
+	void restoreUISession(TRId startTRId, AsyncCallback<TRId> callback);
 
 	void getUriFromResolver(UriResolverSession uriResolverSession,
 			AsyncCallback<String> callback);
 
+	// PeriodDataType
+	void getPeriodDataTypes(AsyncCallback<ArrayList<PeriodDataType>> callback);
+
+	void getHierarchicalRelationshipForPeriodDataTypes(
+			PeriodDataType periodDataType,
+			AsyncCallback<ArrayList<PeriodDataType>> callback);
+
+	// ValueDataFormat
+	void getValueDataFormatsMap(
+			AsyncCallback<HashMap<ColumnDataType, ArrayList<ValueDataFormat>>> callback);
+
+	void getValueDataFormatsOfColumnDataType(ColumnDataType columnDataType,
+			AsyncCallback<ArrayList<ValueDataFormat>> callback);
+
 	// TabularResource
 	void getCurrentTRId(AsyncCallback<TRId> callback);
 
@@ -112,6 +140,8 @@ public interface TDGWTServiceAsync {
 	void setTabResourceInformation(TabResource tabResource,
 			AsyncCallback<Void> callback);
 
+	void setTabResourceToFinal(TRId trId, AsyncCallback<Void> callback);
+
 	void getTRCreationDate(TRId trId, AsyncCallback<String> callback);
 
 	void setTabResource(TabResource tabResource, AsyncCallback<Void> callback);
@@ -130,13 +160,19 @@ public interface TDGWTServiceAsync {
 
 	void getTRMetadata(TRId trId, AsyncCallback<ArrayList<TRMetadata>> callback);
 
+	void getTimeTableId(PeriodDataType periodDataType,
+			AsyncCallback<Long> callback);
+
 	void getColumns(AsyncCallback<ArrayList<ColumnData>> callback);
 
 	void getColumns(TRId trId, AsyncCallback<ArrayList<ColumnData>> callback);
 
 	void getColumnWithViewColumnIncluded(TRId trId,
 			AsyncCallback<ArrayList<ColumnData>> callback);
-
+	
+	void getColumnWithOnlyViewColumnInRel(TRId trId,
+			AsyncCallback<ArrayList<ColumnData>> callback);
+	
 	void getColumnsForStatistical(TRId trId,
 			AsyncCallback<ArrayList<ColumnData>> callback);
 
@@ -176,7 +212,12 @@ public interface TDGWTServiceAsync {
 
 	void getValidationColumns(TRId trId, String columnName,
 			AsyncCallback<ArrayList<ColumnData>> callback);
+	
+	void getValidationColumns(String columnLocalId, TRId trId,
+			AsyncCallback<ArrayList<ColumnData>> callback);
 
+	void startValidationsDelete(TRId trId, AsyncCallback<String> callback);
+	
 	// RollBack
 	void startRollBack(RollBackSession rollBackSession,
 			AsyncCallback<String> callback);
@@ -188,6 +229,9 @@ public interface TDGWTServiceAsync {
 
 	void setShareTemplate(ShareTemplate shareTemplate,
 			AsyncCallback<Void> callback);
+	
+	void setShareRule(ShareRule shareRule,
+			AsyncCallback<Void> callback);
 
 	// CodelistPagingLoaded
 	void setCodelistsPagingLoader(AsyncCallback<Void> callback);
@@ -277,7 +321,11 @@ public interface TDGWTServiceAsync {
 
 	void startLabelColumn(LabelColumnSession labelColumnSession,
 			AsyncCallback<String> callback);
-
+	
+	void startChangeColumnsPosition(ChangeColumnsPositionSession changeColumnsPositionSession,
+			AsyncCallback<Void> callback);
+	
+	
 	/*
 	 * void startSplitColumn(SplitColumnSession
 	 * splitColumnSession,AsyncCallback<Void> callback);
@@ -303,8 +351,9 @@ public interface TDGWTServiceAsync {
 	// Replace Operation
 	void startReplaceColumn(ReplaceColumnSession replaceColumnSession,
 			AsyncCallback<String> callback);
-	
-	void startReplaceByExternal(ReplaceByExternalSession replaceByExternalSession,
+
+	void startReplaceByExternal(
+			ReplaceByExternalSession replaceByExternalSession,
 			AsyncCallback<String> callback);
 
 	// Templates
@@ -361,8 +410,13 @@ public interface TDGWTServiceAsync {
 
 	void getBackgroundOperationMonitor(
 			BackgroundOperationMonitorSession backgroundOperationMonitorSession,
-			AsyncCallback<ArrayList<OperationMonitor>> callback);
-
+			AsyncCallback<ArrayList<BackgroundOperationMonitor>> callback);
+	
+	void getBackgroundOperationMonitorForSpecificTask(
+			OperationMonitorSession operationMonitorSession,
+			AsyncCallback<OperationMonitor> callback);
+			
+	
 	// File Upload Monitor
 	void getFileUploadMonitor(AsyncCallback<FileUploadMonitor> callback);
 
@@ -376,6 +430,9 @@ public interface TDGWTServiceAsync {
 	void removeResource(RemoveResourceSession removeResourceSession,
 			AsyncCallback<Void> callback);
 
+	void saveResource(SaveResourceSession saveResourceSession,
+			AsyncCallback<Void> callback);
+
 	// GIS MAP
 	void startMapCreation(MapCreationSession mapCreationSession,
 			AsyncCallback<String> callback);
@@ -385,4 +442,22 @@ public interface TDGWTServiceAsync {
 			StatisticalOperationSession statisticalOperationSession,
 			AsyncCallback<String> callback);
 
+	// Chart
+	void startChartTopRating(ChartTopRatingSession chartTopRatingSession,
+			AsyncCallback<String> callback);
+
+	// Geospatial
+	void startGeospatialCreateCoordinates(
+			GeospatialCreateCoordinatesSession geospatialCreateCoordinatesSession,
+			AsyncCallback<String> callback);
+
+	void startGeospatialDownscaleCSquare(
+			GeospatialDownscaleCSquareSession geospatialDownscaleCSquareSession,
+			AsyncCallback<String> callback);
+		
+	// Geometry
+	void startGeometryCreatePoint(
+			GeometryCreatePointSession geometryCreatePointSession,
+			AsyncCallback<String> callback);
+
 }
