@@ -7,7 +7,8 @@ import java.io.Serializable;
 import java.util.ArrayList;
 
 import org.gcube.portlets.user.td.gwtservice.shared.destination.Destination;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
 
 /**
  * 
@@ -19,19 +20,22 @@ public class CSVExportSession implements Serializable {
 
 	private static final long serialVersionUID = 407790340509190329L;
 
-	protected String id;
-	protected Destination destination;
-	protected String itemId;
-	protected String fileName;
-	protected String fileDescription;
-	protected ArrayList<ColumnData> columns;
-	protected String encoding;
-	protected String separator;
-	protected boolean exportViewColumns;
+	private String id;
+	private Destination destination;
+	private String itemId;
+	private String fileName;
+	private String fileDescription;
+	private ArrayList<ColumnData> columns;
+	private String encoding;
+	private String separator;
+	private boolean exportViewColumns;
+	private TabResource tabResource;
 
 	public CSVExportSession() {
 		super();
 	}
+		
+	
 
 	public ArrayList<ColumnData> getColumns() {
 		return columns;
@@ -120,6 +124,16 @@ public class CSVExportSession implements Serializable {
 	public void setExportViewColumns(boolean exportViewColumns) {
 		this.exportViewColumns = exportViewColumns;
 	}
+	
+	public TabResource getTabResource() {
+		return tabResource;
+	}
+
+	public void setTabResource(TabResource tabResource) {
+		this.tabResource = tabResource;
+	}
+
+
 
 	@Override
 	public String toString() {
@@ -127,7 +141,10 @@ public class CSVExportSession implements Serializable {
 				+ ", itemId=" + itemId + ", fileName=" + fileName
 				+ ", fileDescription=" + fileDescription + ", columns="
 				+ columns + ", encoding=" + encoding + ", separator="
-				+ separator + ", exportViewColumns=" + exportViewColumns + "]";
+				+ separator + ", exportViewColumns=" + exportViewColumns
+				+ ", tabResource=" + tabResource + "]";
 	}
+	
+	
 
 }
