@@ -13,7 +13,8 @@ public enum WorkerState {
 	VALIDATING_DATA("Validating Data"), 
 	IN_PROGRESS("In Progress"), 
 	SUCCEDED("Succeded"), 
-	FAILED("Failed");
+	FAILED("Failed"),
+	ABORTED("Aborted");
 
 	/**
 	 * @param text
@@ -28,5 +29,17 @@ public enum WorkerState {
 	public String toString() {
 		return id;
 	}
+	
+	
+	public static WorkerState get(String state) {
+		for(WorkerState ws:values()){
+			if(ws.id.compareTo(state)==0){
+				return ws;
+			}
+		}
+		
+		return WorkerState.FAILED;
+	}
+	
 
 }
